[Intel-gfx] [PATCH i-g-t v3 1/4] lib/igt_kms: Add support for up to 10 planes.

robert.foss at collabora.com robert.foss at collabora.com
Mon Apr 25 15:05:10 UTC 2016


From: Robert Foss <robert.foss at collabora.com>

Increase the number of planes supported to 10.

kmstest_plane_name only previously supported 4 planes,
this patch adds support for up to 10 planes.

Signed-off-by: Robert Foss <robert.foss at collabora.com>
---
 lib/igt_kms.c |  6 ++++++
 lib/igt_kms.h | 11 ++++++++++-
 2 files changed, 16 insertions(+), 1 deletion(-)

diff --git a/lib/igt_kms.c b/lib/igt_kms.c
index ef24a49..36ecd4a 100644
--- a/lib/igt_kms.c
+++ b/lib/igt_kms.c
@@ -320,6 +320,12 @@ const char *kmstest_plane_name(enum igt_plane plane)
 		[IGT_PLANE_1] = "plane1",
 		[IGT_PLANE_2] = "plane2",
 		[IGT_PLANE_3] = "plane3",
+		[IGT_PLANE_4] = "plane4",
+		[IGT_PLANE_5] = "plane5",
+		[IGT_PLANE_6] = "plane6",
+		[IGT_PLANE_7] = "plane7",
+		[IGT_PLANE_8] = "plane8",
+		[IGT_PLANE_9] = "plane9",
 		[IGT_PLANE_CURSOR] = "cursor",
 	};
 
diff --git a/lib/igt_kms.h b/lib/igt_kms.h
index 5c83401..b3fe1b2 100644
--- a/lib/igt_kms.h
+++ b/lib/igt_kms.h
@@ -48,12 +48,21 @@ enum pipe {
 };
 const char *kmstest_pipe_name(enum pipe pipe);
 
 /* We namespace this enum to not conflict with the Android i915_drm.h */
 enum igt_plane {
 	IGT_PLANE_1 = 0,
 	IGT_PLANE_PRIMARY = IGT_PLANE_1,
 	IGT_PLANE_2,
 	IGT_PLANE_3,
+	IGT_PLANE_4,
+	IGT_PLANE_5,
+	IGT_PLANE_6,
+	IGT_PLANE_7,
+	IGT_PLANE_8,
+	IGT_PLANE_9,
 	IGT_PLANE_CURSOR,
 	IGT_MAX_PLANES,
 };
@@ -48,12 +48,21 @@ enum pipe {
 const char *kmstest_pipe_name(enum pipe pipe);
 
-/* We namespace this enum to not conflict with the Android i915_drm.h */
+/**
+ * We namespace this enum to not conflict with the Android i915_drm.h
+ * IGT_PLANE_CURSOR is always the last plane.
+ */
 enum igt_plane {
 	IGT_PLANE_1 = 0,
-- 
2.5.0



More information about the Intel-gfx mailing list